#ifndef NT2_INCLUDE_FUNCTIONS_POLYVALM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_POLYVALM_HPP_INCLUDED

#include <nt2/polynom/include/functions/polyvalm.hpp>

#endif
